Lua_FriendBasePanel = class("Lua_FriendBasePanel", Lua_DisplayObject);
function Lua_FriendBasePanel:ctor(p, skin, type)
    self.type = type;

    self:superCall("ctor", p, skin);
end

function Lua_FriendBasePanel:buildShowItem()
    self:superCall("buildShowItem");

    DataCenter.friendData.curOpenUIType = self.type;

    local tweenId = DataCenter.friendData.tweenId;
    self.friendList = Lua_DragList.new(self.content, 632, 629, Lua_AxisDefine.Vertical);
    self.friendList:setListCell(Lua_FriendItem, 632, 143, 1);
    self.friendList.tweenId = tweenId;
    self.friendList:setLocation(0, 5, 0);
    self.friendList:setCellSpacing(0, 0);

    self:addLuaEvent("SET_FRIENDPANEL_INFO", self, self.setPanelData);
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sGetFriendListInfo(self.type);
end

function Lua_FriendBasePanel:setPanelData()
    self.friendInfoArr = DataCenter.friendData:getFriendType(self.type):getFriendList();
    self.friendList:setArrayData(self.friendInfoArr);
    if #self.friendInfoArr == 0 then
        self.noneObject:SetActive(true);
    else
        self.noneObject:SetActive(false);
    end
end

function Lua_FriendBasePanel:dispose()
    if self.friendList ~= nil then
        self.friendList:dispose();
        self.friendList=nil;
    end

    self:superCall("dispose");
end





--------------------------------------------------





Lua_FriendItem = class("Lua_FriendItem", Lua_ListCell);
function Lua_FriendItem:ctor(p)
    self:superCall("ctor", p,"FriendItem_skin");
end

function Lua_FriendItem:buildShowItem()
    self:superCall("buildShowItem");

    self.onlineTxt:setLocation(76, -24, 0);

    self.avatarItem = Lua_AvatarItem.new(self.content);
    self.avatarItem:setLocation(-245, 0, 0);
    self.avatarItem:setScale(0.8, 0.8);
    self.avatarItem:setAvatarClick(self, self.onHeadImageClick);

    self.addFriendBtn:addClickFuntion(self, self.onCheckClick);
    self.acceptBtn:addClickFuntion(self, self.onAcceptClick);
    self.refuseBtn:addClickFuntion(self, self.onRefuseClick);
    self.delFriendBtn:addClickFuntion(self, self.onCheckClick);
    self.removeFriendBtn:addClickFuntion(self, self.onCheckClick);
end

function Lua_FriendItem:setData(data)
    local selectType = DataCenter.friendData.curOpenUIType;
    self.friendData = DataCenter.friendData:getFriendType(selectType):getFriendItemById(data);
    self.curFriendInfo = self.friendData.show;

    self.avatarItem:setRoleDressUp(self.friendData.show.dress_info);

    self.poewrTxt.text = LanUtil.formateStr(161004, self.curFriendInfo.force);
    self.nameTxt.text = self.curFriendInfo.name;
    -- is_cluster 是否跨服，0为否，1为是
    -- if self.curFriendInfo.is_cluster == 1 and self.curFriendInfo.server_prev ~= nil then
    --     self.nameTxt.text = "["..self.curFriendInfo.server_prev.."]"..self.curFriendInfo.name;
    -- end

    if self.friendData.offlineTick == 0 then
        self.onlineTxt:setLangValue(161005);
    else
        if self.friendData.offlineTick / 3600 < 1 then
            self.onlineTxt.text = LanUtil.formateStr(161006, tostring(Mathf.Floor(self.friendData.offlineTick / 60)));
        elseif self.friendData.offlineTick / 3600 < 24 then
            self.onlineTxt.text = LanUtil.formateStr(161007, tostring(Mathf.Floor(self.friendData.offlineTick / 3600)));
        elseif self.friendData.offlineTick / 3600 < 48 then
            self.onlineTxt.text = LanUtil.formateStr(161008, "1");
        elseif self.friendData.offlineTick / 3600 < 72 then
            self.onlineTxt.text = LanUtil.formateStr(161008, "2");
        else
            self.onlineTxt:setLangValue(161009);
        end
    end

    if selectType == Lua_FriendData.FRIEND_RECOMMEND_SEARCH_TYPE then -- 推荐好友
        self.addFriendBtn:setEnable(true);
        if self.friendData.isApply == 0 then
            self.addFriendBtn:setAltas("friend_altas", "xui_hy_button_1_n"); -- 添加好友
            self.addFriendBtn:resetSize();
            self.addFriendBtn.clickScale = true;
        else
            self.addFriendBtn:setAltas("friend_altas", "ui_hy_button_010_n"); -- 已添加
            self.addFriendBtn:resetSize();
            self.addFriendBtn.clickScale = false;
        end
    elseif selectType == Lua_FriendData.FRIEND_APPLY_TYPE then -- 好友申请
        self.refuseBtn:setEnable(true);
        self.acceptBtn:setEnable(true);
    elseif selectType == Lua_FriendData.FRIEND_TYPE then -- 删除好友
        self.delFriendBtn:setEnable(true);
    elseif selectType == Lua_FriendData.FRIEND_BACKLIST_TYPE then -- 黑名单
        self.removeFriendBtn:setEnable(true);
    end
end

function Lua_FriendItem:onHeadImageClick(go)
    if DataCenter.friendData.curOpenUIType == Lua_FriendData.FRIEND_BACKLIST_TYPE then
        local tipData = {
            des = LanUtil.formateStr(161016, self.curFriendInfo.name);
            owner = self;
            posY = 40,
            btnType = 2;
            titleAtlas = "friend_altas";
            titleSprite = "ui_hy_title_02";
            sureLabel = LanUtil.getValue(161017);
            sureFun = self.onSureBackClick };

        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
        return;
    end
    Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.curFriendInfo.id, self.curFriendInfo.server_flag);
end

function Lua_FriendItem:onCheckClick(go)
    if DataCenter.friendData.curOpenUIType == Lua_FriendData.FRIEND_RECOMMEND_SEARCH_TYPE then -- 添加好友
        self:onAddFriendClick();
    elseif DataCenter.friendData.curOpenUIType == Lua_FriendData.FRIEND_TYPE then -- 删除好友
        self:onRemoveFriendClick();
    elseif DataCenter.friendData.curOpenUIType == Lua_FriendData.FRIEND_BACKLIST_TYPE then -- 黑名单
        Lua_ProxyManager.getProxy("Lua_FriendProxy"):sRemoveBackList(self.curFriendInfo.id);
    end
end

function Lua_FriendItem:onAddFriendClick()
    if DataCenter.friendData:isFriendFull() == true then
        OperateAlert.showLangValue(161018);
        return;
    end

    self.isBacklist = DataCenter.friendData:isBacklistById(tonumber(self.curFriendInfo.id));
    if self.isBacklist == true then
        local tipData = {
            des = LanUtil.getValue(161019);
            owner = self;
            type = 1;
            btnType = 1;
            sureFun = self.onSureAddClick };

        Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
        return;
    end

    self:onSureAddClick();
end

function Lua_FriendItem:onSureAddClick()
    -- 加好友先移除黑名单
    if self.isBacklist then
        Lua_ProxyManager.getProxy("Lua_FriendProxy"):sRemoveBackList(tonumber(self.curFriendInfo.id));
    end
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sApplyFriend(tonumber(self.curFriendInfo.id), self.curFriendInfo.server_flag);
end

function Lua_FriendItem:onSureBackClick()
    Lua_WindowUtil.openWin("Lua_PlayerReportWindow", Lua_WinParam.ACTION_OPEN, self.curFriendInfo);
end

function Lua_FriendItem:onRemoveFriendClick(go)
    local tipData = {
        des = LanUtil.formateStr(161020, self.curFriendInfo.name);
        owner = self;
        btnType = 1;
        titleAtlas = "friend_altas";
        titleSprite = "ui_hy_title_02";
        sureFun = self.onSureRemoveClick };

    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_FriendItem:onSureRemoveClick()
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sRemoveFriend(self.curFriendInfo.id);
end

function Lua_FriendItem:onAcceptClick(go)
    local isFull = DataCenter.friendData:isFriendFull();
    if isFull then
        OperateAlert.showLangValue(161018);
        return;
    end

    local isBacklist = DataCenter.friendData:isBacklistById(tonumber(self.curFriendInfo.id));
    if isBacklist then
        local tipData = {
            des = LanUtil.getValue(161019);
            owner = self;
            btnType = 1;
            titleAtlas = "friend_altas";
            titleSprite = "ui_hy_title_02";
            sureFun = self.onSureAcceptClick };

        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
        return;
    end
    
    self:onSureAcceptClick();
end

function Lua_FriendItem:onSureAcceptClick()
    -- local playerInfo = Array();
    -- playerInfo:add({playerId = self.curFriendInfo.id});
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sCheckApplyFriend(3, self.curFriendInfo.id); -- playerInfo
end

function Lua_FriendItem:onRefuseClick(go)
    -- local playerInfo = Array();
    -- playerInfo:add({playerId = self.curFriendInfo.id});
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sCheckApplyFriend(4, self.curFriendInfo.id); -- playerInfo
    OperateAlert.showLangValue(161039);
end

function Lua_FriendItem:dispose()
    if self.avatarItem ~= nil then
        self.avatarItem:dispose();
        self.avatarItem = nil;
    end
    
    self:superCall("dispose");
end