Lua_FriendBaseWindow = class("Lua_FriendBaseWindow", Lua_Window);
function Lua_FriendBaseWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_FriendBaseWindow";
    self.skinName = "FriendWindow_skin";
    self.showBlackMask = true;
    self.isClickClose = true;
    self.showClose = true;
end

function Lua_FriendBaseWindow:buildShowItem()
    self:superCall("buildShowItem");

    -- self.btnClose:setLocation(294, 420, 0);

    self:updateFriendPointTxt();

    local tweenId = DataCenter.friendData.tweenId;
    self.friendList = Lua_DragList.new(self.content, 632, 739, Lua_AxisDefine.Vertical);
    self.friendList.tweenId = tweenId;
    self.friendList:setLocation(0, 1, 0);
    self.friendList:setListCell(Lua_FriendCell, 632, 143, 1);

    self.rewardRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Friend_Reward);
    self.rewardRedPoint:setLocation(254, -444, 0);
    self.rewardRedPoint:setRectAnchor(1);

    self.manageRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Friend_Manage_Apply);
    self.manageRedPoint:setLocation(-87, -444, 0);
    self.manageRedPoint:setRectAnchor(1);

    self.tipsBtn:addClickFuntion(self, self.onTipsBtnClick);
    self.manageBtn:addClickFuntion(self, self.onManageBtnClick);
    self.rewardBtn:addClickFuntion(self, self.onRewardBtnClick);

    self:addLuaEvent("SET_FRIENDPANEL_INFO", self, self.setPanelData);
    self:addLuaEvent("UPDATA_FRIEND_SENDRECBTN", self, self.updateSendRecBtn);
    self:addLuaEvent("MONEY_UPDATE", self, self.updateFriendPointCount);--道具数量增加时，更新友情点数量
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sGetFriendListInfo(Lua_FriendData.FRIEND_TYPE);
end

-- 道具增加时，判断兑换道具列表是否有元素满足，红点
function Lua_FriendBaseWindow:updateFriendPointCount(dic)
    if dic ~= nil and dic[Lua_ResourcesDefine.FRIENDSHIP] ~= nil then -- 道具数量增加时
         self:updateFriendPointTxt();
    end
end

function Lua_FriendBaseWindow:updateFriendPointTxt()
    self.friendPointCount.text = numberTrans(DataCenter.moneyData:getMoney(Lua_ResourcesDefine.FRIENDSHIP));
end

function Lua_FriendBaseWindow:setPanelData(val)
    if val ~= Lua_FriendData.FRIEND_TYPE then
        return;
    end

    local friendData = DataCenter.friendData;
    local friendInfo = friendData:getFriendType(Lua_FriendData.FRIEND_TYPE);
    self.friendInfoArr = friendInfo:getFriendList();
    if #self.friendInfoArr == 0 then
        self.noneObject:SetActive(true);
        self.tipTxt:setLangValue(161035);
        self.friendList:clearList();
    else
        self.noneObject:SetActive(false);
        self.friendList:setArrayData(self.friendInfoArr);
    end

    self:updateSendRecBtn();

    local maxCount = getConfig("friend_const", "friend_limit", "value");
    self.friendCount.text = #self.friendInfoArr.."/"..maxCount;
    self.giveTxt.text = LanUtil.formateStr(161000, friendData.sendTotalCount.."/".. friendInfo.sendMaxCount);
end

function Lua_FriendBaseWindow:updateSendRecBtn()
    self.grayState = not DataCenter.friendData:checkGiftRedState();
    self.rewardBtn:setGray(self.grayState);
end

function Lua_FriendBaseWindow:onTipsBtnClick(go)
    local tipData = { des = LanUtil.getValue(161001), posX = 170, posY = -505 };
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_FriendBaseWindow:onManageBtnClick(go)
    Lua_WindowUtil.openWin("Lua_FriendManageWindow", Lua_WinParam.ACTION_OPEN, 1);
end

function Lua_FriendBaseWindow:onRewardBtnClick(go)
    if self.grayState then
        OperateAlert.showLangValue(161002); -- 无可操作项
        return;
    end

    local goodFriendInfo = DataCenter.friendData:getFriendType(Lua_FriendData.FRIEND_TYPE);
    if DataCenter.friendData.sendTotalCount < goodFriendInfo.sendMaxCount and goodFriendInfo.sendGiftState then
        Lua_ProxyManager.getProxy("Lua_FriendProxy"):sReceiveGiftsOfFriend(); -- 一键赠送
    end

    if not goodFriendInfo.receiveLimitState and goodFriendInfo.receiveGiftState then
        Lua_ProxyManager.getProxy("Lua_FriendProxy"):sReceiveGiftsOfFriend(); -- 一键领取
    end
end

function Lua_FriendBaseWindow:dispose()
    if self.friendList ~= nil then
        self.friendList:dispose();
        self.friendList = nil
    end
    
    self:superCall("dispose");
end





--------------------------------------------------





Lua_FriendCell = class("Lua_FriendCell", Lua_ListCell);
function Lua_FriendCell:ctor(p)
    self:superCall("ctor", p, "FriendItem_skin");
end

function Lua_FriendCell:buildShowItem()
    self:superCall("buildShowItem");

    self.avatarItem = Lua_AvatarItem.new(self.content);
    self.avatarItem:setLocation(-237, 0, 0);
    self.avatarItem:setAvatarClick(self, self.onHeadImageClick);
    self.avatarItem:setScale(0.8, 0.8);

    self.chatBtn:setEnable(true);
    self.sentBtn:setEnable(true);
    -- self.sentIcon:setEnable(true);

    self.sentBtn:addClickFuntion(self, self.onSentClick);
    self.chatBtn:addClickFuntion(self, self.onChatClick);
end

function Lua_FriendCell:setData(data)
    self.data = data;
    self.friendData = DataCenter.friendData:getFriendType(Lua_FriendData.FRIEND_TYPE):getFriendItemById(data);--.show;
    if self.friendData == nil then return; end
    self.avatarItem:setRoleDressUp(self.friendData.show.dress_info);

    self.nameTxt.text = self.friendData.show.name;
    self.poewrTxt.text = LanUtil.formateStr(161004, self.friendData.show.force);

    self.sentBtn:setGray(false);
    if self.friendData.giftsentCount < self.friendData.limitSentCount then
        if self.friendData.giftGetInfo == 0 then
            self.sentBtn:setAltas("friend_altas", "xui_hy_button_8_n");
        else
            self.sentBtn:setAltas("friend_altas", "xui_hy_button_11_n");
        end
    else
        if self.friendData.giftGetInfo == 0 then
            self.sentBtn:setAltas("friend_altas", "xui_hy_button_8_n");
            self.sentBtn:setGray(true);
        else
            self.sentBtn:setAltas("friend_altas", "xui_hy_button_11_n");
        end
    end

    if self.friendData.offlineTick == 0 then
        self.onlineTxt:setLangValue(161005);
    else
        if self.friendData.offlineTick / 3600 < 1 then
            self.onlineTxt.text = LanUtil.formateStr(161006,tostring(Mathf.Floor(self.friendData.offlineTick / 60)));
        elseif self.friendData.offlineTick / 3600 < 24 then
            self.onlineTxt.text = LanUtil.formateStr(161007,tostring(Mathf.Floor(self.friendData.offlineTick / 3600)));
        elseif self.friendData.offlineTick / 3600 < 48 then
            self.onlineTxt.text = LanUtil.formateStr(161008,"1");
        elseif self.friendData.offlineTick / 3600 < 72 then
            self.onlineTxt.text = LanUtil.formateStr(161008,"2");
        else
            self.onlineTxt:setLangValue(161009);
        end
    end
end

function Lua_FriendCell:onHeadImageClick(go)
    Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.friendData.show.id, self.friendData.show.server_flag);
end

function Lua_FriendCell:onSentClick(go)
    if self.friendData.giftGetInfo == 0 then -- 送礼
        local sendTotalCount = DataCenter.friendData.sendTotalCount;
        if sendTotalCount >= self.friendData.maxSentCount then
            OperateAlert.showLangValue(161010);
            return;
        end

        if self.friendData.giftsentCount < self.friendData.limitSentCount then
            Lua_ProxyManager.getProxy("Lua_FriendProxy"):sGiveGiftToFriend(self.data);
        else
            OperateAlert.showLangValue(161040);
        end
    else -- 收礼
        Lua_ProxyManager.getProxy("Lua_FriendProxy"):sReceiveGiftOfFriend(self.data);
    end
end

function Lua_FriendCell:onChatClick(go)
    local dic = {
        id = self.data;
        sex = DataCenter.roleData.sex;
        level = self.friendData.show.level;
        name = self.friendData.show.name;
        dress_info = self.friendData.show.dress_info;
    };
    DataCenter.chatData:setShowPrivateList(dic);
    DataCenter.chatData.selectPrivate = self.data;

    Lua_WindowUtil.openWin("Lua_ChatWindow", Lua_WinParam.ACTION_OPEN, Lua_ChatData.CHANNEL_FRIEND);
    Lua_WindowUtil.openWin("Lua_FriendBaseWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_FriendCell:dispose()
    if self.avatarItem ~= nil then
        self.avatarItem:dispose();
        self.avatarItem = nil;
    end

    self:superCall("dispose");
end