Lua_PlayerInfoWindow = class("Lua_PlayerInfoWindow", Lua_Window);
function Lua_PlayerInfoWindow:ctor()
    self:superCall("ctor");
    
    self.windowName = "Lua_PlayerInfoWindow";
    self.skinName="PlayerInfoWindow_skin";
    self.showClose = true;
    self.showBlackMask = true;
    self.isClickClose = true;
end

function Lua_PlayerInfoWindow:buildShowItem()
    self:superCall("buildShowItem");

    self:hideInitSkinData();
    -- self.btnClose:setLocation(303, 264, 0);
    self.avatarItem = Lua_AvatarItem.new(self.content);
    self.avatarItem:setSiblingIndex(1);
    self.avatarItem:setLocation(-210, 250, 0);

    self.forceNum = Lua_NumberImage.new(self.content);
    self.forceNum:setLocation(168, -107, 0);
    self.forceNum.pivot = 1;
    self.forceNum.numOffsetX = -2;
    self.forceNum.numAtlas = "number";
    self.forceNum.preStr = "xui_zl1_number_0";

    self.heroList = Lua_ItemIconList.new(self.content);
    self.heroList.pivot = 1;
    self.heroList:setLayout(141, 152, 6)
    self.heroList:setLocation(-234, -192, 0);
    self.heroList.scaleVal = 0.7;
    self.heroList.canClick = true;

    self.reportBtn:setLangValue(161047);
    self.reportBtn:addClickFuntion(self, self.onReportBtnClick);
    self.playBtn:setLangValue(161048);
    self.playBtn:addClickFuntion(self, self.onPlayBtnClick);
    self.moveToBacklistBtn:setLangValue(161049);
    self.moveToBacklistBtn:addClickFuntion(self, self.onMoveToBacklistBtnClick);
    self.chatBtn:addClickFuntion(self, self.onChatBtnClick);
    self.collectionbookSp:addClickFuntion(self, self.onCollectionbookSpClick);
end

function Lua_PlayerInfoWindow:hideInitSkinData()
    self.topWarTxt.text = nil;
    self.playerNameTxt.text = nil;
    self.playerLegionTxt.text = nil;
    self.heroCountTxt.text = nil;
    self.skinCountTxt.text = nil;
    self.flashCountTxt.text = nil;
    self.collectionCountTxt.text = nil;
    self.palyerTitleIcon:setEnable(false);
end

function Lua_PlayerInfoWindow:showWin(param)
    self:superCall("showWin", param);
    
    self.playerId = tonumber(param.show.id);
    self:setPanelInfo(param);
end

function Lua_PlayerInfoWindow:setPanelInfo(playerInfo)
    if playerInfo == nil then
        return;
    end
    self.playerInfo = playerInfo.show;
    self:updateCountTxt(playerInfo.collection_info);

    self.avatarItem:setRoleDressUp(self.playerInfo.dress_info);
    self.avatarItem:setRoleLevel(self.playerInfo.level);
    self.avatarItem:setRoleVip(self.playerInfo.vip);

    local palyerTitleId = DataCenter.roleData:getDressUpId(Lua_DressUpDefine.MAINTYPE_TITLE, playerInfo.show.dress_info);
    local palyerTitleInfo = DataCenter.roleUtil:getDressUpVoById(palyerTitleId);
    if palyerTitleInfo ~= nil then
        self.palyerTitleIcon:setEnable(true);
        self.palyerTitleIcon:setAltas(palyerTitleInfo.atlas, palyerTitleInfo.sprite);
        self.palyerTitleIcon:resetSize();
    else
        self.palyerTitleIcon:setEnable(false);
    end

    self.playerNameTxt.text = playerInfo.show.name;
    self.forceNum.num = playerInfo.show.force;
    self.playerLegionTxt:setLangValue(161045);

    local hasLeague = playerInfo.show.league_id ~= nil and tonumber(playerInfo.show.league_id) > 0 and playerInfo.show.league_name ~= nil and stringWidth(playerInfo.show.league_name) > 0; 
    if hasLeague then
        local menber = DataCenter.allianceUtil:getLeagueIdentityByPosition(playerInfo.show.league_position) or "";
        self.playerLegionTxt.text = LanUtil.formateStr(161043, playerInfo.show.league_name, menber);
    end

    self.chatBtn.label = DataCenter.friendData:isFriendById(self.playerId) == false and LanUtil.getValue(161025) or LanUtil.getValue(161026);

    self.playerHeroInfo = playerInfo.lineup;
    local heroVo;
    local list = playerInfo.lineup;
    local heroInforArr = Array()
    for i=1, #list do
        heroVo = Lua_HeroVo.new(list[i].hero_id);
        heroVo:fromServer(list[i]);
        heroVo.otherLineup = playerInfo.lineup;
        heroVo.bSelfRole = tonumber(tostring(playerInfo.show.id)) == DataCenter.roleData.roleId;--是否是自己信息(英雄tips上的装备Tips用到)
        heroInforArr:add(heroVo);
    end
    -- heroInforArr:sort("location",false);
    self.heroList:setArrayData(heroInforArr);
    DataCenter.heroData.otherRoleId = playerInfo.show.id;--记录其他玩家id(用于查看玩家英雄加成项属性)

    if playerInfo.segment_lvl and playerInfo.segment_lvl > 0 then
        local config = DataCenter.peakDuelUtil:getSegmentInfoByid(playerInfo.segment_lvl);
        self.topWarTxt.text = LanUtil.formateStr(161050, config.name);
    else
        self.topWarTxt:setLangValue(161044); -- 暂无巅峰对决
    end
end

function Lua_PlayerInfoWindow:updateCountTxt(countData)
    if countData ~= nil then
        local curCount = tonumber(countData.hero_num) -- 英雄数量(收藏册普卡)
        local totalCount = DataCenter.collectionBookUtil.ordinaryCardTotalCount;
        self.heroCountTxt.text = LanUtil.formateStr(161042, curCount, totalCount);

        curCount = tonumber(countData.skin_num) -- 皮肤数量(收藏册皮肤闪卡)
        totalCount = DataCenter.collectionBookUtil.skinCardCount;
        self.skinCountTxt.text = LanUtil.formateStr(161042, curCount, totalCount);

        curCount = tonumber(countData.flash_card_num) -- 闪卡数量(收藏册英雄闪卡)
        totalCount = DataCenter.collectionBookUtil.heroCardCount;
        self.flashCountTxt.text = LanUtil.formateStr(161042, curCount, totalCount);


        curCount = tonumber(countData.collection_num) -- 藏品数量
        totalCount = DataCenter.collectionData.totalCollectionCount;
        self.collectionCountTxt.text = LanUtil.formateStr(161042, curCount, totalCount);
    end
end

function Lua_PlayerInfoWindow:onReportBtnClick(go)
    local tipData = {
        des = LanUtil.formateStr(161028, self.playerNameTxt.text),
        posY = 40,
        btnType = 2,
        h = 408,
        owner = self,
        sureLabel = LanUtil.getValue(161017),
        sureFun = self.onSureReportBtnClick
    };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_PlayerInfoWindow:onSureReportBtnClick(go)
    Lua_WindowUtil.openWin("Lua_PlayerReportWindow", Lua_WinParam.ACTION_OPEN, self.playerInfo);
end

function Lua_PlayerInfoWindow:onCollectionbookSpClick()
    if DataCenter.funcOpenData:isOpened(10239, true) then 
        local playerId = tonumber(self.playerInfo.id);
        DataCenter.collectionBookData:setOtherPlayerInfo(self.playerInfo);
        Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sFindOtherCards(playerId);
    end
end

function Lua_PlayerInfoWindow:onPlayBtnClick(go)
    if #self.playerHeroInfo == 0 then
        OperateAlert.show(LanUtil.formateStr(161033, self.playerInfo.name));
        return;
    end

    local friendInfo = DataCenter.friendData:getFriendType(Lua_FriendData.FRIEND_TYPE);
    local info = friendInfo:getFriendItemById(self.playerId);
    if info == nil then
        OperateAlert.showLangValue(161034);
        return;
    end

    --发送开始战斗
    Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(Lua_FightDefine.TEMPLATE_ID_FRIENT, 0, self.playerId);
end

function Lua_PlayerInfoWindow:onMoveToBacklistBtnClick(go)
    if not DataCenter.funcOpenData:isOpened(10265) then
        return;
    end
    local tipData = {
        titleAtlas = "friend_altas",
        titleSprite = "ui_hy_title_02",
        des = LanUtil.formateStr(161027, self.playerNameTxt.text),
        btnType = 1,
        owner = self,
        sureFun = self.onTipsSurenClick
    };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_PlayerInfoWindow:onTipsSurenClick()
    Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_CLOSE);
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sAddBackList(self.playerId, self.playerInfo.server_flag);
end

function Lua_PlayerInfoWindow:onChatBtnClick(go)
    if not DataCenter.funcOpenData:isOpened(10231, true) then
        return;
    end

    local isFriend = DataCenter.friendData:isFriendById(tonumber(self.playerId));
    self.chatBtn.label = isFriend == false and LanUtil.getValue(161025) or LanUtil.getValue(161026);

    if isFriend == true then
        local dic = {
            id = tonumber(self.playerId);
            sex = DataCenter.roleData.sex;
            level = self.playerInfo.level;
            name = self.playerInfo.name;
            -- head_icon = self.playerInfo.head_id;
            dress_info = self.playerInfo.dress_info;
        };
        DataCenter.chatData:setShowPrivateList(dic);
        DataCenter.chatData.selectPrivate = tonumber(self.playerId);

        Lua_WindowUtil.openWin("Lua_ChatWindow", Lua_WinParam.ACTION_OPEN, Lua_ChatData.CHANNEL_FRIEND);
        Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_CLOSE);
    else
        self:onAddFriendClick();
    end
end

function Lua_PlayerInfoWindow:onAddFriendClick()
    if DataCenter.friendData:isFriendFull() == true then
        OperateAlert.showLangValue(161018);
        return;
    end

    self.isBacklist = DataCenter.friendData:isBacklistById(self.playerId);
    if self.isBacklist == true then
        local tipData = { des = LanUtil.getValue(161019), btnType = 1, owner = self, sureFun = self.onSureAddClick };
        Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
        return;
    end

    self:onSureAddClick();
end

function Lua_PlayerInfoWindow:onSureAddClick()
    -- 加好友先移除黑名单
    if self.isBacklist then
        Lua_ProxyManager.getProxy("Lua_FriendProxy"):sRemoveBackList(self.playerId);
    end
    Lua_ProxyManager.getProxy("Lua_FriendProxy"):sApplyFriend(self.playerId, self.playerInfo.server_flag);
    Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_PlayerInfoWindow:dispose()
    if self.forceNum ~= nil then
        self.forceNum:dispose();
        self.forceNum = nil;
    end
    if self.avatarItem ~= nil then
        self.avatarItem:dispose();
        self.avatarItem = nil;
    end
    if self.heroList ~= nil then
       self.heroList:dispose();
       self.heroList = nil;
    end
    DataCenter.heroData.otherRoleId = nil;
    self:superCall("dispose");
end